@@ -146,7 +146,7 @@
          "$PrefixLineNo" "$PSCal" "$RunOff" "$Saturday" "$September"
          "$SimpleCal" "$SortByDate" "$SortByPrio" "$SortByTime" "$SubsIndent"
          "$Sunday" "$SuppressImplicitWarnings" "$SuppressLRM" "$SysInclude" "$T" "$Td"
-         "$TerminalBackground" "$Thursday" "$TimeSep" "$Tm" "$Today"
+         "$TerminalBackground" "$Thursday" "$TimeSep" "$TimetIs64bit" "$Tm" "$Today"
          "$Tomorrow" "$Tt" "$Tuesday" "$Tw" "$Ty" "$U" "$Ud" "$Um"
          "$UntimedFirst" "$Use256Colors" "$UseBGVTColors" "$UseTrueColors"
          "$UseVTColors" "$Uw" "$Uy" "$Was" "$Wednesday")
@@ -166,21 +166,23 @@
    (list "_" "abs" "access" "adawn" "adusk" "ampm" "ansicolor" "args" "asc"
          "baseyr" "char" "choose" "coerce" "columns" "current" "date"
          "datepart" "datetime" "dawn" "day" "daysinmon" "defined" "dosubst"
-         "dusk" "easterdate" "escape" "evaltrig" "filedate" "filedatetime" "filedir"
-         "filename" "getenv" "hebdate" "hebday" "hebmon" "hebyear" "hour"
-         "htmlescape" "htmlstriptags" "iif" "index" "isany" "isdst" "isleap"
-         "isomitted" "language" "localtoutc" "lower" "max" "min" "minsfromutc"
-         "minute" "mon" "monnum" "moondate" "moondatetime" "moonphase"
-         "moontime" "multitrig" "ndawn" "ndusk" "nonomitted" "now" "ord"
-         "orthodoxeaster" "ostype" "pad" "plural" "psmoon" "psshade"
-         "realcurrent" "realnow" "realtoday" "rows" "sgn" "shell" "shellescape"
-         "slide" "soleq" "stdout" "strlen" "substr" "sunrise" "sunset" "time"
-         "timepart" "timezone" "today" "trig" "trigback" "trigdate"
-         "trigdatetime" "trigdelta" "trigduration" "trigeventduration"
-         "trigeventstart" "trigfrom" "trigger" "triginfo" "trigpriority" "trigrep"
+         "dusk" "easterdate" "escape" "evaltrig" "filedate" "filedatetime"
+         "filedir" "filename" "getenv" "hebdate" "hebday" "hebmon" "hebyear"
+         "hour" "htmlescape" "htmlstriptags" "iif" "index" "isany" "isdst"
+         "isleap" "isomitted" "language" "localtoutc" "lower" "max" "min"
+         "minsfromutc" "minute" "mon" "monnum" "moondate" "moondatetime"
+         "moonphase" "moonrise" "moonrisedir" "moonset" "moonsetdir" "moontime"
+         "multitrig" "ndawn" "ndusk" "nonomitted" "now" "ord" "orthodoxeaster"
+         "ostype" "pad" "plural" "psmoon" "psshade" "realcurrent" "realnow"
+         "realtoday" "rows" "sgn" "shell" "shellescape" "slide" "soleq"
+         "stdout" "strlen" "substr" "sunrise" "sunset" "time" "timepart"
+         "timezone" "today" "trig" "trigback" "trigdate" "trigdatetime"
+         "trigdelta" "trigduration" "trigeventduration" "trigeventstart"
+         "trigfrom" "trigger" "triginfo" "trigpriority" "trigrep"
          "trigscanfrom" "trigtags" "trigtime" "trigtimedelta" "trigtimerep"
          "triguntil" "trigvalid" "typeof" "tzconvert" "upper" "utctolocal"
-         "value" "version" "weekno" "wkday" "wkdaynum" "year")
+         "value" "version" "weekno" "wkday" "wkdaynum" "year"
+         )
    #'(lambda (a b) (> (length a) (length b)))))
 
 ;;; faces
