@@ -6,7 +6,7 @@
 /*  which you can customize.                                   */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2024 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -20,10 +20,10 @@
 /* western hemisphere.                                                 */
 /*                                                                     */
 /* The default values are initially set to the city hall in Ottawa,    */
-/* Ontario, Canada.    */
+/* Ontario, Canada.                                                    */
 /*---------------------------------------------------------------------*/
-#define DEFAULT_LATITUDE 45.420556
-#define DEFAULT_LONGITUDE -75.689722
+#define DEFAULT_LATITUDE 45.42055555555555
+#define DEFAULT_LONGITUDE -75.68944444444445
 #define LOCATION "Ottawa"
 
 /*---------------------------------------------------------------------*/
@@ -68,12 +68,6 @@
 /**********************************************************************/
 /**********************************************************************/
 
-/*---------------------------------------------------------------------*/
-/* WANT_SHELL_ESCAPING:  Define this if you want special shell         */
-/* characters to be escaped with a backslash for the -k option.        */
-/*---------------------------------------------------------------------*/
-#define WANT_SHELL_ESCAPING 1
-
 /*---------------------------------------------------------------------*/
 /* BASE: The base year for date calculation.  NOTE!  January 1 of the  */
 /*       base year MUST be a Monday, else Remind will not work!        */
@@ -109,16 +103,6 @@
 /*---------------------------------------------------------------------*/
 #define MAX_STR_LEN 65535
 
-/*---------------------------------------------------------------------*/
-/* OP_STACK_SIZE: The size of the operator stack for expr. parsing     */
-/*---------------------------------------------------------------------*/
-#define OP_STACK_SIZE 100
-
-/*---------------------------------------------------------------------*/
-/* VAL_STACK_SIZE: The size of the operand stack for expr. parsing     */
-/*---------------------------------------------------------------------*/
-#define VAL_STACK_SIZE 100
-
 /*---------------------------------------------------------------------*/
 /* INCLUDE_NEST: How many nested INCLUDES do we handle?                */
 /*---------------------------------------------------------------------*/
