@@ -40,8 +40,8 @@ check_subst_args(UserFunc *f, int n)
     if (f->nargs == n) {
         return 1;
     }
-    Wprint(tr("Function `%s' defined at %s:%d should take %d argument%s, but actually takes %d"),
-           f->name, f->filename, f->lineno, n, (n == 1 ? "" : "s"), f->nargs);
+    Wprint(tr("Function `%s' defined at %s(%s) should take %d argument%s, but actually takes %d"),
+           f->name, f->filename, line_range(f->lineno_start, f->lineno), n, (n == 1 ? "" : "s"), f->nargs);
     return 0;
 }
 /***************************************************************/
@@ -79,6 +79,7 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig *tt, int dse,
     int origLen = DBufLen(dbuf);
     int altmode;
     int r;
+    int origtime;
     Value v;
     UserFunc *func;
 
@@ -87,6 +88,7 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig *tt, int dse,
     if (tt) {
         tim = tt->ttime;
     }
+    origtime = tim;
     if (tim == NO_TIME) tim = curtime;
     tdiff = tim - curtime;
     adiff = ABS(tdiff);
@@ -123,7 +125,7 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig *tt, int dse,
         pm = (h < 12) ? tr("am") : tr("pm");
     }
 
-    hh = (h == 12) ? 12 : h % 12;
+    hh = (h == 12 || h == 0) ? 12 : h % 12;
 
     ch = curtime / 60;
     cmin = curtime % 60;
@@ -149,7 +151,7 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig *tt, int dse,
     if (r != OK) {
         cpm = (h < 12) ? tr("am") : tr("pm");
     }
-    chh = (ch == 12) ? 12 : ch % 12;
+    chh = (ch == 0 || ch == 12) ? 12 : ch % 12;
 
     func = FindUserFunc("subst_ordinal");
     if (func && check_subst_args(func, 1)) {
@@ -405,6 +407,12 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig *tt, int dse,
                     Eprint("%s", GetErr(r));
                 }
             }
+            if (origtime == NO_TIME) {
+                if ((c >= '0' && c <= '9') || (c == '!')) {
+                    Wprint(tr("`%%%c' substitution sequence should not be used without an AT clause"), c);
+                }
+            }
+
             switch(UPPER(c)) {
             case 'A':
                 if (altmode == '*' || !strcmp(tr("on"), "")) {
