@@ -897,11 +897,21 @@ void Wprint(char const *fmt, ...)
     va_list argptr;
 
 
+    /* We can't use line_range because caller might have used it */
     if (FileName) {
-        if (strcmp(FileName, "-"))
-            (void) fprintf(ErrFp, "%s(%d): ", FileName, LineNo);
-        else
-            (void) fprintf(ErrFp, "-stdin-(%d): ", LineNo);
+        if (strcmp(FileName, "-")) {
+            if (LineNoStart == LineNo) {
+                (void) fprintf(ErrFp, "%s(%d): ", FileName, LineNo);
+            } else {
+                (void) fprintf(ErrFp, "%s(%d:%d): ", FileName, LineNoStart, LineNo);
+            }
+        } else {
+            if (LineNoStart == LineNo) {
+                (void) fprintf(ErrFp, "-stdin-(%d): ", LineNo);
+            } else {
+                (void) fprintf(ErrFp, "-stdin-(%d:%d): ", LineNoStart, LineNo);
+            }
+        }
     }
 
     va_start(argptr, fmt);
@@ -933,7 +943,12 @@ void Eprint(char const *fmt, ...)
         fname = "-stdin-";
     }
     if (FreshLine) {
-        (void) fprintf(ErrFp, "%s(%d): ", fname, LineNo);
+        /* We can't use line_range because caller might have used it */
+        if (LineNo == LineNoStart) {
+            (void) fprintf(ErrFp, "%s(%d): ", fname, LineNo);
+        } else {
+            (void) fprintf(ErrFp, "%s(%d:%d): ", fname, LineNoStart, LineNo);
+        }
     } else {
         fprintf(ErrFp, "       ");
     }
@@ -1117,8 +1132,7 @@ int DoIf(ParsePtr p)
             syndrome = IF_TRUE | BEFORE_ELSE;
             Eprint("%s", GetErr(r));
         } else
-            if ( (v.type != STR_TYPE && v.v.val) ||
-                 (v.type == STR_TYPE && strcmp(v.v.str, "")) ) {
+            if (truthy(&v)) {
                 syndrome = IF_TRUE | BEFORE_ELSE;
             } else {
                 syndrome = IF_FALSE | BEFORE_ELSE;
@@ -2022,7 +2036,6 @@ SaveLastTimeTrig(TimeTrig const *t)
 void
 System(char const *cmd, int is_queued)
 {
-    int r;
     pid_t kid;
     int fd;
     int status;
@@ -2055,15 +2068,12 @@ System(char const *cmd, int is_queued)
         }
     }
     /* This is the child process or original if we never forked */
-    r = system(cmd);
+    (void) system(cmd);
     if (do_exit) {
         /* In the child process, so exit! */
         exit(0);
     }
-
-    if (r == 0) {
-        return;
-    }
+    return;
 }
 
 char const *
