@@ -342,7 +342,7 @@ int main(int argc, char *argv[])
     while (!feof(stdin)) {
         DBufGets(&buf, stdin);
         if (first_line && (!strcmp(DBufValue(&buf), "["))) {
-            fprintf(stderr, "Rem2PS: It appears that you have invoked Remind with the -ppp option.\n        Please use either -p or -pp, but not -ppp.\n");
+            fprintf(stderr, "Rem2PS: It appears that you have invoked Remind with the -ppp option.\n        Please use either -p or -pp, but not -ppp.  Also, Rem2PS does\n        not support weekly calendars, so do not use -p+ or -pp+.\n");
             exit(EXIT_FAILURE);
         }
         first_line = 0;
@@ -1222,7 +1222,7 @@ int DoQueuedPs(void)
                 if (moonsize < 0) {
                     size = "DaySize 2 div";
                 } else {
-                    sprintf(buffer, "%d", moonsize);
+                    snprintf(buffer, sizeof(buffer), "%d", moonsize);
                     size = buffer;
                 }
 
@@ -1235,7 +1235,7 @@ int DoQueuedPs(void)
                         if (fontsize < 0) {
                             fsize = "EntrySize";
                         } else {
-                            sprintf(fbuffer, "%d", fontsize);
+                            snprintf(fbuffer, sizeof(fbuffer), "%d", fontsize);
                             fsize = fbuffer;
                         }
                         printf("/EntryFont findfont %s scalefont setfont (",
@@ -1273,7 +1273,7 @@ int DoQueuedPs(void)
                     if (fontsize < 0) {
                         fsize = "EntrySize";
                     } else {
-                        sprintf(fbuffer, "%d", fontsize);
+                        snprintf(fbuffer, sizeof(fbuffer), "%d", fontsize);
                         fsize = fbuffer;
                     }
                     printf("/EntryFont findfont %s scalefont setfont (",
